import { Component, OnInit } from "@angular/core";
import { CapabilityLauncherService } from "./services/capability-launcher.service";
import { CapabilityRequest } from "./model/capability-request";
import { CapabilityExecution } from "./model/capability-execution";

@Component({
  selector: "app-workspaces",
  templateUrl: "./workspaces.component.html",
  styleUrls: ["./workspaces.component.scss"],
})
export class WorkspacesComponent implements OnInit {
  public capabilityRequests: Array<CapabilityRequest> = [];
  public capabilityExecutions: Array<CapabilityExecution> = [];

  constructor(private capabilityLauncher: CapabilityLauncherService) {}

  ngOnInit(): void {}

  /**
   * OnClick method that creates a capability request for the null capability and submits it
   */
  nullButtonOnClick(): void {
    this.launchCapability("null", "-g");
  }

  /**
   * OnClick method that creates a capability request for the test_download capability and submits it
   */
  downloadButtonOnClick(): void {
    this.launchCapability(
      "test_download",
      "shared/workspaces/test/test_data/spool/724126739/17A-109.sb33151331.eb33786546.57892.65940042824"
    );
  }

  /**
   * Method that uses the capabilityLauncher service to launch a capability
   * @param capabilityName  Name of capability
   * @param parameters  Parameters of capability request
   */
  launchCapability(capabilityName: string, parameters: string): void {
    // Create capability request
    this.capabilityLauncher.createRequest(capabilityName, parameters).subscribe(
      (requestResponse) => {
        this.capabilityRequests.push(requestResponse);
        if (requestResponse.id) {
          // Capability request created; ID found
          // Submit capability request
          this.capabilityLauncher
            .submit(capabilityName, requestResponse.id)
            .subscribe(
              (submitResponse) => {
                this.capabilityExecutions.push(submitResponse);
              },
              (error) => {
                console.log(error);
              }
            );
        }
      },
      (error) => {
        console.log(error);
      }
    );
  }
}
